# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing the various textual links.

## 1. Test

    dictionary DictWithDefaults {
        sequence<long> arrayWithDefaultEmpty = [];
        DictWithDefaults dictWithDefaultEmpty = {};
    };

`arrayWithDefaultEmpty`, of type sequence<long>, defaulting to `[]`

  This OPTIONAL member contains a list of things.

`dictWithDefaultEmpty`, of type DictWithDefaults, defaulting to `{}`

  This OPTIONAL member contains a recursive thing.

## Index

### Terms defined by this specification

- arrayWithDefaultEmpty, in §1
- dictWithDefaultEmpty, in §1
- DictWithDefaults, in §1

https://heycam.github.io/webidl/#idl-long Referenced in:

- 1. Test (2)

### Terms defined by reference

- [WebIDL] defines the following terms:
  - long

## References

### Normative References

[WebIDL]
  Boris Zbarsky. Web IDL. 15 December 2016. ED. URL: https://heycam.github.io/webidl/

## IDL Index

    dictionary DictWithDefaults {
        sequence<long> arrayWithDefaultEmpty = [];
        DictWithDefaults dictWithDefaultEmpty = {};
    };

#dictdef-dictwithdefaults Referenced in:

- 1. Test (2)

#dom-dictwithdefaults-arraywithdefaultempty Referenced in:

- 1. Test

#dom-dictwithdefaults-dictwithdefaultempty Referenced in:

- 1. Test